@@ -11,26 +11,24 @@ PyGTK widget for NeoVim uses the depracated method.
 
 Consider the bare minimum script:
 
-```
-w = Gtk.Window()
-w.connect('destroy', Gtk.main_quit)
-w.resize(800, 600)
+    w = Gtk.Window()
+    w.connect('destroy', Gtk.main_quit)
+    w.resize(800, 600)
 
-vim = Embedded()
-w.add(vim)
+    vim = Embedded()
+    w.add(vim)
 
 
-def on_vim_started(widget):
-  # Show the window once Vim has started and given use the right Gui options,
-  # i.e. the font.
-  w.show_all()
+    def on_vim_started(widget):
+      # Show the window once Vim has started and given use the right Gui options,
+      # i.e. the font.
+      w.show_all()
 
-# the `started` signal tells us Vim is up and running and configured enough to
-# display.
-vim.connect('started', on_vim_started)
+    # the `started` signal tells us Vim is up and running and configured enough to
+    # display.
+    vim.connect('started', on_vim_started)
 
-Gtk.main()
-```
+    Gtk.main()
 
 The startup flow is a bit annoying because we don't want to display the widget
 until Vim is started and has told us the value of `guifont` otherwise we will
@@ -111,7 +109,7 @@ class Highlight:
 
 
 class Color:
-  """BeoVim color with conversion to RGB"""
+  """NeoVim color with conversion to RGB"""
 
   def __init__(self, color_value):
     self.r = ((color_value >> 16) & 255) / 256.0
@@ -204,6 +202,8 @@ class Embedded(Gtk.DrawingArea, logs.LoggerMixin):
   cid = GObject.Property(type=int, default=0)
   mode = GObject.Property(type=Mode)
 
+  button_drag = False
+
   def __init__(self):
     Gtk.DrawingArea.__init__(self)
     logs.LoggerMixin.__init__(self)
